| Title: | Describe Data in R Using Common Descriptive Statistics |
|---|---|
| Description: | Allows users to quickly and easily describe data using common descriptive statistics. |
| Authors: | Paul Hendricks [aut, cre] |
| Maintainer: | Paul Hendricks <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0.9000 |
| Built: | 2026-05-14 08:56:40 UTC |
| Source: | https://github.com/paulhendricks/describer |
describe takes vectors and data.frames and returns a data.frame containing important descriptive statistics.
describe(.x) ## S3 method for class 'numeric' describe(.x) ## S3 method for class 'character' describe(.x) ## S3 method for class 'data.frame' describe(.x) ## Default S3 method: describe(.x)describe(.x) ## S3 method for class 'numeric' describe(.x) ## S3 method for class 'character' describe(.x) ## S3 method for class 'data.frame' describe(.x) ## Default S3 method: describe(.x)
.x |
a vector or data.frame to be described. |
a data.frame containing important descriptive statistics.
numeric: Method for numeric.
character: Method for character.
data.frame: Method for data.frames.
default: Method for default.
# Example describe(mtcars) describe(iris) describe(state.name)# Example describe(mtcars) describe(iris) describe(state.name)
describe_nonnumeric takes non-numeric atomic vectors and returns a data.frame containing important descriptive statistics.
describe_nonnumeric(.x)describe_nonnumeric(.x)
.x |
a non-numeric atomic vector to be described. |
a data.frame containing important descriptive statistics.
# Example describe_nonnumeric(letters)# Example describe_nonnumeric(letters)
describe_numeric takes numeric vectors and returns a data.frame containing important descriptive statistics.
describe_numeric(.x)describe_numeric(.x)
.x |
a numeric atomic vector or data.frame to be described. |
a data.frame containing important descriptive statistics.
# Example describe_numeric(1:100)# Example describe_numeric(1:100)
describer: Describe Data in R Using Common Descriptive Statistics
pd_describe takes vectors and data.frames and returns a data.frame containing important descriptive statistics.
pd_describe(.x)pd_describe(.x)
.x |
a vector or data.frame to be described. |
a data.frame containing important descriptive statistics.
# Example pd_describe(mtcars) pd_describe(iris)# Example pd_describe(mtcars) pd_describe(iris)